==> resource-registry-4.1.0-20221114.170529-97-sources.jar: org/gcube/informationsystem/resourceregistry/utils/PropagationConstraintOrient.java <==
package org.gcube.informationsystem.resourceregistry.utils;

import java.util.Map;

import org.gcube.informationsystem.model.reference.properties.PropagationConstraint;

import com.orientechnologies.orient.core.record.impl.ODocument;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
public class PropagationConstraintOrient extends ODocument implements org.gcube.informationsystem.model.reference.properties.PropagationConstraint {
	
	public PropagationConstraintOrient() {
		super(PropagationConstraint.NAME);
	}
	
	protected PropagationConstraintOrient(String iClassName) {
		super(iClassName);
	}

	@Override
	public RemoveConstraint getRemoveConstraint() {
		return RemoveConstraint.valueOf((String) this.field(PropagationConstraint.REMOVE_PROPERTY));
	}

	@Override
	public void setRemoveConstraint(RemoveConstraint removeConstraint) {
		this.field(PropagationConstraint.REMOVE_PROPERTY, removeConstraint.name());
	}

	@Override
	public AddConstraint getAddConstraint() {
		return AddConstraint.valueOf((String) this.field(PropagationConstraint.ADD_PROPERTY));
	}

	@Override
	public void setAddConstraint(AddConstraint addConstraint) {
		this.field(PropagationConstraint.ADD_PROPERTY, addConstraint.name());
	}

	@Override
	public Map<String, Object> getAdditionalProperties() {
		return null;
	}

	@Override
	public void setAdditionalProperties(Map<String, Object> additionalProperties) {
		
	}

	@Override
	public Object getAdditionalProperty(String key) {
		return null;
	}

	@Override
	public void setAdditionalProperty(String key, Object value) {
			
	}
	
}

==> resource-registry-4.2.0-20230301.144547-8-sources.jar: org/gcube/informationsystem/resourceregistry/utils/PropagationConstraintOrient.java <==
package org.gcube.informationsystem.resourceregistry.utils;

import java.util.Map;

import org.gcube.informationsystem.model.reference.properties.PropagationConstraint;

import com.orientechnologies.orient.core.record.impl.ODocument;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
public class PropagationConstraintOrient extends ODocument implements org.gcube.informationsystem.model.reference.properties.PropagationConstraint {
	
	public PropagationConstraintOrient() {
		super(PropagationConstraint.NAME);
	}
	
	protected PropagationConstraintOrient(String iClassName) {
		super(iClassName);
	}

	@Override
	public DeleteConstraint getDeleteConstraint() {
		return DeleteConstraint.valueOf((String) this.field(PropagationConstraint.DELETE_PROPERTY));
	}

	@Override
	public void setDeleteConstraint(DeleteConstraint deleteConstraint) {
		this.field(PropagationConstraint.DELETE_PROPERTY, deleteConstraint.name());
	}
	
	@Override
	public RemoveConstraint getRemoveConstraint() {
		return RemoveConstraint.valueOf((String) this.field(PropagationConstraint.REMOVE_PROPERTY));
	}

	@Override
	public void setRemoveConstraint(RemoveConstraint removeConstraint) {
		this.field(PropagationConstraint.REMOVE_PROPERTY, removeConstraint.name());
	}

	@Override
	public AddConstraint getAddConstraint() {
		return AddConstraint.valueOf((String) this.field(PropagationConstraint.ADD_PROPERTY));
	}

	@Override
	public void setAddConstraint(AddConstraint addConstraint) {
		this.field(PropagationConstraint.ADD_PROPERTY, addConstraint.name());
	}

	@Override
	public Map<String, Object> getAdditionalProperties() {
		return null;
	}

	@Override
	public void setAdditionalProperties(Map<String, Object> additionalProperties) {
		
	}

	@Override
	public Object getAdditionalProperty(String key) {
		return null;
	}

	@Override
	public void setAdditionalProperty(String key, Object value) {
			
	}
	
}
